==> reb_1.26.0.zip: reb/doc/reb.R <==
###################################################
### chunk number 1: 
###################################################
#line 56 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpp7CGA1/R.INSTALL34e65b3f/reb/inst/doc/reb.Rnw"
library(reb)
library(idiogram)


###################################################
### chunk number 2: 
###################################################
#line 84 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpp7CGA1/R.INSTALL34e65b3f/reb/inst/doc/reb.Rnw"
data(mcr.eset)
data(idiogramExample)

ref.ix <- grep("MNC",colnames(mcr.eset@exprs))
mcr.sum <- summarizeByRegion(mcr.eset@exprs,vai.chr,ref=ref.ix)


###################################################
### chunk number 3: 
###################################################
#line 103 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpp7CGA1/R.INSTALL34e65b3f/reb/inst/doc/reb.Rnw"
complex.ix <-grep("MCR",colnames(mcr.eset@exprs))
regmap(mcr.sum[,complex.ix],col=.rwb,scale=c(-3,3))


###################################################
### chunk number 4: 
###################################################
#line 119 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpp7CGA1/R.INSTALL34e65b3f/reb/inst/doc/reb.Rnw"
mcr.cset <- smoothByRegion(mcr.eset@exprs,vai.chr,ref=ref.ix)


###################################################
### chunk number 5: 
###################################################
#line 129 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpp7CGA1/R.INSTALL34e65b3f/reb/inst/doc/reb.Rnw"
data <- mcr.cset[,complex.ix]
data[abs(data) < 1.96] <- NA
op <- par(no.readonly=TRUE)
layout(rbind(c(1,2),c(3,4)))
for(i in c("2","5","11","6")) 
idiogram(data,vai.chr,method="i",col=.rwb,dlim=c(-4,4),chr=i)
par(op)


###################################################
### chunk number 6: 
###################################################
#line 143 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpp7CGA1/R.INSTALL34e65b3f/reb/inst/doc/reb.Rnw"
idiogram(mcr.cset[,complex.ix],vai.chr,
method="m",chr=5,dlim=c(-5,5),type="l",lty=1)

==> reb_1.28.0.zip: reb/doc/reb.R <==
###################################################
### chunk number 1: 
###################################################
#line 56 "reb.Rnw"
library(reb)
library(idiogram)


###################################################
### chunk number 2: 
###################################################
#line 84 "reb.Rnw"
data(mcr.eset)
data(idiogramExample)

ref.ix <- grep("MNC",colnames(mcr.eset@exprs))
mcr.sum <- summarizeByRegion(mcr.eset@exprs,vai.chr,ref=ref.ix)


###################################################
### chunk number 3: 
###################################################
#line 103 "reb.Rnw"
complex.ix <-grep("MCR",colnames(mcr.eset@exprs))
regmap(mcr.sum[,complex.ix],col=.rwb,scale=c(-3,3))


###################################################
### chunk number 4: 
###################################################
#line 119 "reb.Rnw"
mcr.cset <- smoothByRegion(mcr.eset@exprs,vai.chr,ref=ref.ix)


###################################################
### chunk number 5: 
###################################################
#line 129 "reb.Rnw"
data <- mcr.cset[,complex.ix]
data[abs(data) < 1.96] <- NA
op <- par(no.readonly=TRUE)
layout(rbind(c(1,2),c(3,4)))
for(i in c("2","5","11","6")) 
idiogram(data,vai.chr,method="i",col=.rwb,dlim=c(-4,4),chr=i)
par(op)


###################################################
### chunk number 6: 
###################################################
#line 143 "reb.Rnw"
idiogram(mcr.cset[,complex.ix],vai.chr,
method="m",chr=5,dlim=c(-5,5),type="l",lty=1)
